Model extensions — django-extensions 0.9.1-beta documentation

### Navigation

- index
- next |
- previous |
- django-extensions 0.9.1-beta documentation »

# Model extensions

synopsis: | Current Model Extensions

## Current Database Model Extensions

- TimeStampedModel - TimeStampedModel An abstract base class model that provides self-managed “created” and “modified” fields.

### Navigation

- index
- next |
- previous |
- django-extensions 0.9.1-beta documentation »